@@ -2,9 +2,8 @@
 
 
 package Vim::Debug;
-{
-  $Vim::Debug::VERSION = '0.9';
-}
+
+our $VERSION = '0.901'; # VERSION
 
 use Carp;
 use IO::Pty;
@@ -22,6 +21,7 @@ my $RUNTIME_ERROR  = "runtime error";
 my $APP_EXITED     = "application exited";
 my $DBGR_READY     = "debugger ready";
 
+
 has invoke   => ( is => 'ro', isa => 'Str', required => 1 );
 has language => ( is => 'ro', isa => 'Str', required => 1 );
 
@@ -56,6 +56,8 @@ sub BUILD {
     apply_all_roles($self, 'Vim::Debug::' . $self->language);
 }
 
+
+
 sub start {
     my $self = shift or confess;
 
@@ -191,68 +193,63 @@ sub state {
 1;
 
 __END__
+
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Vim::Debug - Perl wrapper around a command line debugger
 
-=head1 VERSION
-
-version 0.9
-
 =head1 SYNOPSIS
 
-If you are new to the Vim::Debug project please read the L<Vim::Debug::Manual> first.
-
     package Vim::Debug;
 
-    my $debugger = Vim::Debug->new;
+    my $debugger = Vim::Debug->new(
+        language => 'Perl',                    # required
+        invoke   => 'perl -Ilib -d t/perl.pl', # required
+    );
+
     $debugger->start;
-    $debugger->write('s'); # step
     sleep(1) until $debugger->read;
-    print $debugger->line;
-    print $debugger->file;
-    print $debugger->output;
-    $debugger->write('q'); # quit
+    print "line:   " . $debugger->line . "\n";
+    print "file:   " . $debugger->file . "\n";
+    print "output: " . $debugger->output . "\n";
+
+    $debugger->step;          sleep(1) until $debugger->read;
+    $debugger->next;          sleep(1) until $debugger->read;
+    $debugger->write('help'); sleep(1) until $debugger->read;
+
+    $debugger->quit; 
 
 =head1 DESCRIPTION
 
-The Vim::Debug project integrates the Perl debugger with Vim, allowing
-developers to visually step through their code and examine variables.  
+If you are new to Vim::Debug please read the user manual,
+L<Vim::Debug::Manual>, first.
 
-If you are new to the Vim::Debug project please read the L<Vim::Debug::Manual> first.
+Vim::Debug is an object oriented wrapper around the Perl command line
+debugger.  In theory the debugger could be for any language -- not just Perl.
+But only Perl is supported currently.
 
-Please note that this code is in beta and these libraries will be changing
-radically in the near future.
+The read() method is non blocking.  This allows a user to send an interrupt
+when they get stuck in an infinite loop.
 
-=head1 PREREQUISITES
+=head1 ATTRIBUTES
 
-Vim compiled with +signs and +perl.
+=head2 invoke
 
-=head1 INSTALL INSTRUCTIONS
+=head2 language
 
-Replace $VIMHOME with your vim configuration directory.  (/home/username/.vim on unix.)
+=head2 stop
 
-=head2 With cpanm
+=head2 line
 
-    TODO
+=head2 file
 
-=head2 With github
+=head2 value
 
-    git clone git@github.com:kablamo/VimDebug.git
-    cd VimDebug
-    perl Makefile.PL
-    make
-    sudo make install
-    cp -r vim/* $VIMHOME/
-
-=head1 Vim::Debug
-
-The Vim::Debug class provides an object oriented wrapper around the Perl
-command line debugger.  
-
-Note that the read() method is non blocking. 
+=head2 status
 
 =head1 FUNCTIONS
 
@@ -297,48 +294,25 @@ debugger command is returned as an arrayref of strings.
 
 Dies if no translation is found.                                                                                               
 
-=head2 line($number)
-
-If $number parameter is used, the line class attribute is set using that
-value.  If no parameters are passed, the current value of the line
-attribute is returned.
-
-=head2 file($path)
-
-If $path parameter is used, the file class attribute is set using that
-value.  If no parameters are passed, the current value of the file
-attribute is returned.
-
-=head2 dbgrPromptRegex($regex)
-
-If $regex parameter is used, the dbgrPromptRegex class attribute is set using that
-value.  If no parameters are passed, the current value of the dbgrPromptRegex 
-attribute is returned.
-
 =head1 SEE ALSO
 
-L<Devel::ebug>, L<perldebguts>
+L<Vim::Debug::Manual>, L<Vim::Debug::Perl>, L<Devel::ebug>, L<perldebguts>
+
+=head1 BUGS
+
+In retrospect its possible there is a better solution to this.  Perhaps
+directly hooking directly into the debugger rather than using regexps to parse
+stdout and stderr?
 
 =head1 AUTHOR
 
-Eric Johnson, cpan at iijo : :dot: : org
-
-=head1 COPYRIGHT
-
-Copyright (C) 2003 - 3090, Eric Johnson
-
-This module is GPL.
-
-=head1 AUTHOR
-
-Eric Johnson <vimdebug at iijo dot org>
+Eric Johnson <kablamo at iijo dot nospamthanks dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Eric Johnson.
+This software is copyright (c) 2013 by Eric Johnson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
