@@ -2,9 +2,8 @@
 
 
 package Vim::Debug::Perl;
-{
-  $Vim::Debug::Perl::VERSION = '0.9';
-}
+
+our $VERSION = '0.901'; # VERSION
 
 use Moose::Role;
 
@@ -67,30 +66,23 @@ sub parseOutput {
 1;
 
 __END__
+
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Vim::Debug::Perl - Perl debugger interface.
 
-=head1 VERSION
-
-version 0.9
-
-=head1 SYNOPSIS
-
-If you are new to the Vim::Debug project please read the L<Vim::Debug::Manual> first.
-
-    package Vim::Debug::Perl
-
-    my $debugger = Vim::Debug::Perl->new;
-    $debugger->next;
-    $debugger->step;
-
 =head1 DESCRIPTION
 
-This module inherits from Vim::Debug.  See that module for a more in depth
-explanation.  This module only handles the Perl specific bits.
+If you are new to Vim::Debug please read the user manual,
+L<Vim::Debug::Manual>, first.
+
+This module is a role that is dynamically applied to an Vim::Debug instance.
+L<Vim::Debug> represents a debugger.  This module only handles the Perl
+specific bits.  Theoretically there might be a Ruby or Python role someday.
 
 =head1 DEBUGGER OUTPUT REGEX CLASS ATTRIBUTES
 
@@ -107,7 +99,7 @@ They return a regex and ignore all values passed to them.
 
 =head1 TRANSLATION CLASS ATTRIBUTES
 
-These attributes are used by Vim::Debug::Daemon to convert commands from the
+These attributes are used to convert commands from the
 communication protocol to commands the Perl debugger can recognize.  For
 example, the communication protocol uses the keyword 'next' while the Perl
 debugger uses 'n'.
@@ -144,14 +136,13 @@ Returns undef.
 
 =head1 AUTHOR
 
-Eric Johnson <vimdebug at iijo dot org>
+Eric Johnson <kablamo at iijo dot nospamthanks dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Eric Johnson.
+This software is copyright (c) 2013 by Eric Johnson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
